@@ -25,7 +25,7 @@ def summary(
     col_width: int = 25,
     dtypes: Optional[List[Type[torch.Tensor]]] = None,
     batch_dim: int = 0,
-    device: torch.device = None,
+    device: Optional[torch.device] = None,
     **kwargs: Any,
 ) -> ModelStatistics:
     """
@@ -38,9 +38,10 @@ def summary(
         model (Module): Model to summarize
         input_data (Sequence of Sizes or Tensors):
             Example input tensor of the model (dtypes inferred from model input).
+            NOTE: multiple parameters to the model should be passed as *args, NOT as a List.
             - OR -
             Shape of input data as a List/Tuple/torch.Size (dtypes must match model input,
-            default to FloatTensors). NOTE: For scalars, use torch.Size([]).
+            default is FloatTensors). NOTE: For scalar parameters, use torch.Size([]).
         use_branching (bool): Whether to use the branching layout for the printed output.
         max_depth (int): number of nested layers to traverse (e.g. Sequentials)
         verbose (int):
@@ -53,7 +54,9 @@ def summary(
         dtypes (List or None): for multiple inputs or args, must specify the size of both inputs.
             You must also specify the types of each parameter here.
         batch_dim (int): batch_dimension of input data
-        args, kwargs: Other arguments used in `model.forward` function
+        device (torch.Device): If specified, uses this torch device for the model and model's input.
+            Else defaults to torch.cuda.is_available().
+        args, kwargs: Other arguments used in `model.forward` function.
     """
     assert verbose in (0, 1, 2)
     summary_list: List[LayerInfo] = []
@@ -61,18 +64,31 @@ def summary(
     idx: Dict[int, int] = {}
     apply_hooks(model, model, max_depth, summary_list, hooks, idx, batch_dim)
 
-    if isinstance(input_data, torch.Tensor):
+    if device is None:
+        device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
+
+    if torch.is_tensor(input_data):
+        # input must be a single tensor. If not, it should be passed as args.
         input_size = get_correct_input_sizes(input_data.size())
-        x = [input_data]
+        x = [input_data.to(device)]
     else:
         if dtypes is None:
-            dtypes = [torch.FloatTensor] * len(input_data)
+            # Add more options if requested: mkldnn, opengl, opencl, ideep, hip, msnpu
+            if device.type == "cpu":
+                dtypes = [torch.FloatTensor] * len(input_data)
+            elif device.type == "cuda":
+                dtypes = [torch.cuda.FloatTensor] * len(input_data)
+            else:
+                raise ValueError("Specified device not supported. Please submit a GitHub issue.")
         input_size = get_correct_input_sizes(input_data)
         x = get_input_tensor(input_size, batch_dim, dtypes, device)
 
+    args = [t.to(device) if torch.is_tensor(t) else t for t in args]
+    kwargs = {k: kwargs[k].to(device) if torch.is_tensor(kwargs[k]) else k for k in kwargs}
+
     try:
         with torch.no_grad():
-            _ = model(*x, *args, **kwargs)
+            _ = model.to(device)(*x, *args, **kwargs)
     except Exception:
         print(f"Failed to run torchsummary, printing sizes of executed layers: {summary_list}")
         raise
@@ -90,8 +106,6 @@ def summary(
 
 def get_input_tensor(input_size, batch_dim, dtypes, device):
     """ Get input_tensor with batch size 2 for use in model.forward() """
-    if device is None:
-        device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
     x = []
     for size, dtype in zip(input_size, dtypes):
         # add batch_size of 2 for BatchNorm
